package App::podispell;
our $VERSION = '0.001002';
$VERSION = eval $VERSION;
1;
__END__

=for stopwords
haarg Knop cpan HAARG podispell perl

=head1 NAME

App::podispell - Interactive Pod spell checker

=head1 DESCRIPTION

See L<podispell> for documentation.  This module is not usable directly.

=head1 AUTHOR

haarg - Graham Knop (cpan:HAARG) <haarg@haarg.org>

=head1 CONTRIBUTORS

None yet.

=head1 COPYRIGHT

Copyright (c) 2015 the podispell L</AUTHOR> and L</CONTRIBUTORS>
as listed above.

=head1 LICENSE

This library is free software and may be distributed under the same terms
as perl itself. See L<http://dev.perl.org/licenses/>.

=cut
